@@ -46,9 +46,13 @@ typedef enum dc_sample_type_t {
 	DC_SAMPLE_PPO2,
 	DC_SAMPLE_CNS,
 	DC_SAMPLE_DECO,
-	DC_SAMPLE_GASMIX
+	DC_SAMPLE_GASMIX,
+	DC_SAMPLE_TTS,		// time to surface in seconds
 } dc_sample_type_t;
 
+// Make it easy to test support compile-time with "#ifdef DC_SAMPLE_TTS"
+#define DC_SAMPLE_TTS DC_SAMPLE_TTS
+
 typedef enum dc_field_type_t {
 	DC_FIELD_DIVETIME,
 	DC_FIELD_MAXDEPTH,
@@ -114,13 +118,19 @@ typedef enum parser_sample_flags_t {
 
 #define SAMPLE_FLAGS_SEVERITY_SHIFT 2
 
+#define SAMPLE_FLAGS_SEVERITY_MISSING (0 << SAMPLE_FLAGS_SEVERITY_SHIFT)
+#define SAMPLE_FLAGS_SEVERITY_STATE   (1 << SAMPLE_FLAGS_SEVERITY_SHIFT)
+#define SAMPLE_FLAGS_SEVERITY_INFO    (2 << SAMPLE_FLAGS_SEVERITY_SHIFT)
+#define SAMPLE_FLAGS_SEVERITY_WARN    (3 << SAMPLE_FLAGS_SEVERITY_SHIFT)
+#define SAMPLE_FLAGS_SEVERITY_ALARM   (4 << SAMPLE_FLAGS_SEVERITY_SHIFT)
+
 typedef enum parser_sample_vendor_t {
 	SAMPLE_VENDOR_NONE,
 	SAMPLE_VENDOR_UWATEC_ALADIN,
 	SAMPLE_VENDOR_UWATEC_SMART,
 	SAMPLE_VENDOR_OCEANIC_VTPRO,
 	SAMPLE_VENDOR_OCEANIC_VEO250,
-	SAMPLE_VENDOR_OCEANIC_ATOM2,
+	SAMPLE_VENDOR_OCEANIC_ATOM2
 } parser_sample_vendor_t;
 
 typedef enum dc_water_t {
@@ -170,7 +180,6 @@ typedef unsigned int dc_tankinfo_t;
 #define DC_TANKVOLUME_METRIC	DC_TANKINFO_METRIC
 #define DC_TANKVOLUME_IMPERIAL	DC_TANKINFO_IMPERIAL
 
-
 /*
  * Tank volume
  *
@@ -219,9 +228,9 @@ typedef union dc_sample_value_t {
 	struct {
 		unsigned int type;
 		unsigned int time;
-		const char *name;
 		unsigned int flags;
 		unsigned int value;
+		const char *name;
 	} event;
 	unsigned int rbt;
 	unsigned int heartbeat;
